@@ -29,12 +29,21 @@ use Feature::Compat::Class;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.0.5';
+our $VERSION = '0.1.0';
 
 class Amazon::Sites {
   use Amazon::Site;
 
-  field %sites = _init_sites();
+  field $include :param = [];
+  field $exclude :param = [];
+  field $assoc_codes :param = {};
+  field %sites = _init_sites($assoc_codes, $include, $exclude);
+
+  ADJUST {
+    if (@$include and @$exclude) {
+      die "You can't specify both include and exclude";
+    }
+  }
 
 =head1 METHODS
 
@@ -42,6 +51,17 @@ class Amazon::Sites {
 
 Creates a new Amazon::Sites object.
 
+    my $sites = Amazon::Sites->new;
+
+You can also specify a list of sites to include or exclude:
+
+    # Only include the US site
+    my $sites = Amazon::Sites->new(include => [ 'US' ]);
+    # Exclude the US site
+    my $sites = Amazon::Sites->new(exclude => [ 'US' ]);
+
+At most one of `include` or `exclude` can be specified.
+
 =head2 sites_hash
 
 Returns a hash where the keys are the two-letter country codes and the values are
@@ -73,17 +93,27 @@ Returns a list of L<Amazon::Site> objects, sorted by the sort order.
     return \@sites;
   }
 
-  sub _init_sites {
+  sub _init_sites($assoc_codes, $include, $exclude) {
     my %sites;
     my @cols = qw[code country tldn currency sort];
 
+    my $where = tell DATA;
+
     while (<DATA>) {
       chomp;
       my %site;
       @site{@cols} = split;
+
+      next if @$include and not grep { $site{code} eq $_ } @$include;
+      next if @$exclude and grep { $site{code} eq $_ } @$exclude;
+
+      $site{assoc_code} = $assoc_codes->{$site{code}} if $assoc_codes->{$site{code}};
+
       $sites{$site{code}} = Amazon::Site->new(%site);
     }
 
+    seek DATA, $where, 0;
+
     return %sites;
   }
 
